aboutsummaryrefslogtreecommitdiff
path: root/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/MetaInfoType.java
diff options
context:
space:
mode:
Diffstat (limited to 'moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/MetaInfoType.java')
-rw-r--r--moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/MetaInfoType.java63
1 files changed, 32 insertions, 31 deletions
diff --git a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/MetaInfoType.java b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/MetaInfoType.java
index 9e8a00c..61c4682 100644
--- a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/MetaInfoType.java
+++ b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/MetaInfoType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.15 at 04:11:53 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:50 PM CET
//
@@ -10,34 +10,34 @@ package at.gv.egiz.moasig;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAnyElement;
-import javax.xml.bind.annotation.XmlElement;
-import javax.xml.bind.annotation.XmlSchemaType;
-import javax.xml.bind.annotation.XmlSeeAlso;
-import javax.xml.bind.annotation.XmlType;
-import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
-import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAnyElement;
+import jakarta.xml.bind.annotation.XmlElement;
+import jakarta.xml.bind.annotation.XmlSchemaType;
+import jakarta.xml.bind.annotation.XmlSeeAlso;
+import jakarta.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
+import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
/**
- * <p>Java class for MetaInfoType complex type.
+ * <p>Java-Klasse für MetaInfoType complex type.
*
- * <p>The following schema fragment specifies the expected content contained within this class.
+ * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
* <pre>
- * &lt;complexType name="MetaInfoType">
- * &lt;complexContent>
- * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- * &lt;sequence>
- * &lt;element name="MimeType" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}MimeTypeType"/>
- * &lt;element name="Description" type="{http://www.w3.org/2001/XMLSchema}anyURI" minOccurs="0"/>
- * &lt;any namespace='##other' maxOccurs="unbounded" minOccurs="0"/>
- * &lt;/sequence>
- * &lt;/restriction>
- * &lt;/complexContent>
- * &lt;/complexType>
+ * &lt;complexType name="MetaInfoType"&gt;
+ * &lt;complexContent&gt;
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+ * &lt;sequence&gt;
+ * &lt;element name="MimeType" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}MimeTypeType"/&gt;
+ * &lt;element name="Description" type="{http://www.w3.org/2001/XMLSchema}anyURI" minOccurs="0"/&gt;
+ * &lt;any namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
+ * &lt;/sequence&gt;
+ * &lt;/restriction&gt;
+ * &lt;/complexContent&gt;
+ * &lt;/complexType&gt;
* </pre>
*
*
@@ -55,6 +55,7 @@ public class MetaInfoType {
@XmlElement(name = "MimeType", required = true)
@XmlJavaTypeAdapter(CollapsedStringAdapter.class)
+ @XmlSchemaType(name = "token")
protected String mimeType;
@XmlElement(name = "Description")
@XmlSchemaType(name = "anyURI")
@@ -63,7 +64,7 @@ public class MetaInfoType {
protected List<Object> any;
/**
- * Gets the value of the mimeType property.
+ * Ruft den Wert der mimeType-Eigenschaft ab.
*
* @return
* possible object is
@@ -75,7 +76,7 @@ public class MetaInfoType {
}
/**
- * Sets the value of the mimeType property.
+ * Legt den Wert der mimeType-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -87,7 +88,7 @@ public class MetaInfoType {
}
/**
- * Gets the value of the description property.
+ * Ruft den Wert der description-Eigenschaft ab.
*
* @return
* possible object is
@@ -99,7 +100,7 @@ public class MetaInfoType {
}
/**
- * Sets the value of the description property.
+ * Legt den Wert der description-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -116,7 +117,7 @@ public class MetaInfoType {
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the any property.
*
* <p>
@@ -116,7 +117,7 @@ public class MetaInfoType {
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a <CODE>set</CODE> method for the any property.
*